@@ -18,7 +18,7 @@ class CdmNetComBr(Provider, Std):
         re = self.re.compile('/titulos/[^/]+/[^/]+/[^/]+/([^/]+)')
         return re.search(self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/titulos/{}')
 
     def get_manga_name(self) -> str:
