@@ -8,7 +8,7 @@ class ComicWebNewTypeCom(Provider, Std):
         re = self.re.compile('/contents/[^/]+/([^/]+)')
         return re.search(self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/contents/{}/')
 
     def get_manga_name(self) -> str:
