@@ -10,7 +10,7 @@ class MangaTrCom(Provider, Std):
         idx = self.re.search('-chapter-(.+)\.html', chapter).group(1)
         return '-'.join(idx.split('.'))
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/manga-{}.html')
 
     def get_manga_name(self) -> str:
