@@ -11,7 +11,7 @@ class MangaFreakNet(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'.+_(\d+)', self.chapter[1]).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
