@@ -9,7 +9,7 @@ class MangaLibMe(Provider, Std):
         idx = self.re.search(selector, self.chapter).groups()
         return '-'.join(idx)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
