@@ -18,7 +18,7 @@ class TmoFansCom(Provider, Std):
 
             raise e
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
